@@ -2,13 +2,13 @@ c\BeginDoc
 c
 c\Name: dgetv0
 c
-c\Description: 
+c\Description:
 c  Generate a random initial residual vector for the Arnoldi process.
-c  Force the residual vector to be in the range of the operator OP.  
+c  Force the residual vector to be in the range of the operator OP.
 c
 c\Usage:
 c  call dgetv0
-c     ( IDO, BMAT, ITRY, INITV, N, J, V, LDV, RESID, RNORM, 
+c     ( IDO, BMAT, ITRY, INITV, N, J, V, LDV, RESID, RNORM,
 c       IPNTR, WORKD, IERR )
 c
 c\Arguments
@@ -35,7 +35,7 @@ c          B = 'I' -> standard eigenvalue problem A*x = lambda*x
 c          B = 'G' -> generalized eigenvalue problem A*x = lambda*B*x
 c
 c  ITRY    Integer.  (INPUT)
-c          ITRY counts the number of times that dgetv0 is called.  
+c          ITRY counts the number of times that dgetv0 is called.
 c          It should be set to 1 on the initial call to dgetv0.
 c
 c  INITV   Logical variable.  (INPUT)
@@ -54,11 +54,11 @@ c          The first J-1 columns of V contain the current Arnoldi basis
 c          if this is a "restart".
 c
 c  LDV     Integer.  (INPUT)
-c          Leading dimension of V exactly as declared in the calling 
+c          Leading dimension of V exactly as declared in the calling
 c          program.
 c
 c  RESID   Double precision array of length N.  (INPUT/OUTPUT)
-c          Initial residual vector to be generated.  If RESID is 
+c          Initial residual vector to be generated.  If RESID is
 c          provided, force RESID into the range of the operator OP.
 c
 c  RNORM   Double precision scalar.  (OUTPUT)
@@ -87,7 +87,7 @@ c\References:
 c  1. D.C. Sorensen, "Implicit Application of Polynomial Filters in
 c     a k-Step Arnoldi Method", SIAM J. Matr. Anal. Apps., 13 (1992),
 c     pp 357-385.
-c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly 
+c  2. R.B. Lehoucq, "Analysis and Implementation of an Implicitly
 c     Restarted Arnoldi Iteration", Rice University Technical Report
 c     TR95-13, Department of Computational and Applied Mathematics.
 c
@@ -97,7 +97,7 @@ c     dvout   ARPACK utility routine for vector output.
 c     dlarnv  LAPACK routine for generating a random vector.
 c     dgemv   Level 2 BLAS routine for matrix vector multiplication.
 c     dcopy   Level 1 BLAS that copies one vector to another.
-c     ddot    Level 1 BLAS that computes the scalar product of two vectors. 
+c     ddot    Level 1 BLAS that computes the scalar product of two vectors.
 c     dnrm2   Level 1 BLAS that computes the norm of a vector.
 c
 c\Author
@@ -105,25 +105,27 @@ c     Danny Sorensen               Phuong Vu
 c     Richard Lehoucq              CRPC / Rice University
 c     Dept. of Computational &     Houston, Texas
 c     Applied Mathematics
-c     Rice University           
-c     Houston, Texas            
+c     Rice University
+c     Houston, Texas
 c
-c\SCCS Information: @(#) 
+c\SCCS Information: @(#)
 c FILE: getv0.F   SID: 2.7   DATE OF SID: 04/07/99   RELEASE: 2
 c
 c\EndLib
 c
 c-----------------------------------------------------------------------
 c
-      subroutine dgetv0 
-     &   ( ido, bmat, initv, n, j, v, ldv, resid, rnorm, 
+      subroutine dgetv0
+     &   ( ido, bmat, initv, n, j, v, ldv, resid, rnorm,
      &     ipntr, workd, ierr )
-c 
+c
 c     %----------------------------------------------------%
 c     | Include files for debugging and timing information |
 c     %----------------------------------------------------%
+
+      implicit none
 c
-      include   'debug.h'
+cm      include   'debug.h'
       include   'stat.h'
 c
 c     %------------------%
@@ -157,10 +159,12 @@ c     | Local Scalars & Arrays |
 c     %------------------------%
 c
       logical    first, inits, orth
-      integer    idist, iseed(4), iter, msglvl, jj
+      integer    idist, iseed(4), iter,  jj
+cm      integer    idist, iseed(4), iter, msglvl, jj
       Double precision
      &           rnorm0
-      save       first, iseed, inits, iter, msglvl, orth, rnorm0
+      save       first, iseed, inits, iter, orth, rnorm0
+cm      save       first, iseed, inits, iter, msglvl, orth, rnorm0
 c
 c     %----------------------%
 c     | External Subroutines |
@@ -208,15 +212,15 @@ c
       end if
 c
       if (ido .eq.  0) then
-c 
+c
 c        %-------------------------------%
 c        | Initialize timing statistics  |
 c        | & message level for debugging |
 c        %-------------------------------%
 c
 c         call second (t0)
-         msglvl = mgetv0
-c 
+cm         msglvl = mgetv0
+c
          ierr   = 0
          iter   = 0
          first  = .FALSE.
@@ -235,7 +239,7 @@ c
             idist = 2
             call dlarnv (idist, iseed, n, resid)
          end if
-c 
+c
 c        %----------------------------------------------------------%
 c        | Force the starting vector into the range of OP to handle |
 c        | the generalized problem when B is possibly (singular).   |
@@ -251,7 +255,7 @@ c         call second (t2)
             go to 9000
          end if
       end if
-c 
+c
 c     %-----------------------------------------%
 c     | Back from computing OP*(initial-vector) |
 c     %-----------------------------------------%
@@ -263,13 +267,13 @@ c     | Back from computing B*(orthogonalized-vector) |
 c     %-----------------------------------------------%
 c
       if (orth)  go to 40
-c 
+c
       if (bmat .eq. 'G') then
 c         call second (t3)
 cs         tmvopx = tmvopx + (t3 - t2)
-         tmvopx = 0.0
+ct         tmvopx = 0.0
       end if
-c 
+c
 c     %------------------------------------------------------%
 c     | Starting vector is now in the range of OP; r = OP*r; |
 c     | Compute B-norm of starting vector.                   |
@@ -285,17 +289,17 @@ c      call second (t2)
          ido = 2
          go to 9000
       else if (bmat .eq. 'I') then
-         call dcopy (n, resid, 1, workd, 1)
+         call dcopy (n, resid, 1, workd(:), 1)
       end if
-c 
+c
    20 continue
 c
       if (bmat .eq. 'G') then
 c         call second (t3)
 cs         tmvbx = tmvbx + (t3 - t2)
-         tmvbx = 0.0
+ct         tmvbx = 0.0
       end if
-c 
+c
       first = .FALSE.
       if (bmat .eq. 'G') then
           rnorm0 = ddot (n, resid, 1, workd, 1)
@@ -310,7 +314,7 @@ c     | Exit if this is the very first Arnoldi step |
 c     %---------------------------------------------%
 c
       if (j .eq. 1) go to 50
-c 
+c
 c     %----------------------------------------------------------------
 c     | Otherwise need to B-orthogonalize the starting vector against |
 c     | the current Arnoldi basis using Gram-Schmidt with iter. ref.  |
@@ -326,11 +330,11 @@ c
       orth = .TRUE.
    30 continue
 c
-      call dgemv ('T', n, j-1, one, v, ldv, workd, 1, 
+      call dgemv ('T', n, j-1, one, v, ldv, workd(:), 1,
      &            zero, workd(n+1), 1)
-      call dgemv ('N', n, j-1, -one, v, ldv, workd(n+1), 1, 
-     &            one, resid, 1)
-c 
+      call dgemv ('N', n, j-1, -one, v, ldv, workd(n+1), 1,
+     &            one, resid(n), 1)
+c
 c     %----------------------------------------------------------%
 c     | Compute the B-norm of the orthogonalized starting vector |
 c     %----------------------------------------------------------%
@@ -346,15 +350,15 @@ c      call second (t2)
       else if (bmat .eq. 'I') then
          call dcopy (n, resid, 1, workd, 1)
       end if
-c 
+c
    40 continue
 c
       if (bmat .eq. 'G') then
 c         call second (t3)
 c         tmvbx = tmvbx + (t3 - t2)
-         tmvbx = 0.0
+ct         tmvbx = 0.0
       end if
-c 
+c
       if (bmat .eq. 'G') then
          rnorm = ddot (n, resid, 1, workd, 1)
          rnorm = sqrt(abs(rnorm))
@@ -367,14 +371,14 @@ c     | Check for further orthogonalization. |
 c     %--------------------------------------%
 c
 c      if (msglvl .gt. 2) then
-c          call dvout (logfil, 1, rnorm0, ndigit, 
+c          call dvout (logfil, 1, rnorm0, ndigit,
 c     &                '_getv0: re-orthonalization ; rnorm0 is')
-c          call dvout (logfil, 1, rnorm, ndigit, 
+c          call dvout (logfil, 1, rnorm, ndigit,
 c     &                '_getv0: re-orthonalization ; rnorm is')
 c      end if
 c
       if (rnorm .gt. 0.717*rnorm0) go to 50
-c 
+c
       iter = iter + 1
       if (iter .le. 5) then
 c
@@ -396,7 +400,7 @@ c
          rnorm = zero
          ierr = -1
       end if
-c 
+c
    50 continue
 c
 c      if (msglvl .gt. 0) then
@@ -408,11 +412,11 @@ c         call dvout (logfil, n, resid, ndigit,
 c     &        '_getv0: initial / restarted starting vector')
 c      end if
       ido = 99
-c 
+c
 c      call second (t1)
 cs      tgetv0 = tgetv0 + (t1 - t0)
-      tgetv0 = 0.0
-c 
+ct      tgetv0 = 0.0
+c
  9000 continue
       return
 c
